Enum hive_asar::header::FilePosition
source · [−]pub enum FilePosition {
Offset(u64),
Unpacked,
}Expand description
Whether the file is stored in the archive or is unpacked.
Variants
Offset(u64)
Offset of the file in the archive, indicates the file is stored in it.
Unpacked
Indicates the file is stored outside the archive.