Archive

Struct Archive 

pub struct Archive<R: AsyncRead + AsyncSeek + Unpin> { /* private fields */ }
Generic asar archive reader.

It supports any reader that implements AsyncRead, AsyncSeek and Unpin, and adds more methods if the reader implements Send or (Local)Duplicable.

Implementations

Source

impl<R: AsyncRead + AsyncSeek + Unpin> Archive<R>

pub async fn new(reader: R) -> Result<Self>

Parses an asar archive into Archive.

pub fn reader(&self) -> &R

Returns a reference to its inner reader.

pub fn reader_mut(&mut self) -> &mut R

Returns mutable reference to its inner reader.

It is mostly OK to seek the reader’s cursor, since every time accessing its file will reset the cursor to the file’s position. However, write access will compromise Archive’s functionality. Use with great care!

pub fn into_reader(self) -> R

Drops the inner state and returns the reader.

Source

impl Archive<DuplicableFile>

pub async fn new_from_file(path: impl Into<PathBuf>) -> Result<Self>

Available on crate feature fs only.

Opens a file and parses it into Archive.

Source

impl<R: AsyncRead + AsyncSeek + Unpin> Archive<R>

pub async fn get(&mut self, path: &str) -> Result<File<&mut R>>

Returns a file from the archive by taking mutable reference.

pub fn get_entry(&self, path: &str) -> Option<&Entry>

Returns the entry (“metadata”) of specified path.

Source

impl<R: AsyncRead + AsyncSeek + Duplicable + Unpin> Archive<R>

pub async fn get_owned(&self, path: &str) -> Result<File<R>>

Returns a file from the archive by duplicating the inner reader.

Contrary to Archive::get, it allows multiple read access over a single archive by creating a new file handle for every file. Useful when building a virtual file system like how Electron does.

Source

impl<R: AsyncRead + AsyncSeek + LocalDuplicable + Unpin> Archive<R>

pub async fn get_owned_local(&self, path: &str) -> Result<File<R>>

Returns a file from the archive by duplicating the inner reader, without Sync.

See Archive::get_owned for more information.

Source

impl<R: AsyncRead + AsyncSeek + Send + Unpin> Archive<R>

pub async fn extract(&mut self, path: impl AsRef<Path>) -> Result<()>

Available on crate feature fs only.

Extracts the archive to a folder.

Source

impl<R: AsyncRead + AsyncSeek + Unpin> Archive<R>

pub async fn extract_local(&mut self, path: impl AsRef<Path>) -> Result<()>

Available on crate feature fs only.

Extracts the archive to a folder.

This method is intended for R: !Send. Otherwise, use Archive::extract instead.