pub struct Writer<F: AsyncRead + Unpin> { /* private fields */ }
Asar archive writer.

Implementations

Creates a new, empty archive writer.

Add an entry to the archive.

The entry’s parent directories are created recursively if they do not exist.

size should correspond with content. If size is smaller, exactly size bytes will be written. If size is bigger, the Writer::write method will fail. For convenience, you may want to use add_sized.

Panic

The method panics if normalised path contains no filename, or if the path is already occupied by a previously inserted file.

Adds an empty folder recursively to the archive.

Finishes the archive and writes the content into dest.

Add an entry to the archive.

Similar to Writer::add, but it uses AsyncSeekExt::seek to determine the size of the content.

For more information see Writer::add.

Available on crate feature integrity only.